@@ -17,12 +17,11 @@ package Dist::Zilla::Plugin::TemplateCJM;
 # ABSTRACT: Process templates, including version numbers & changes
 #---------------------------------------------------------------------
 
-our $VERSION = '4.24';
-# This file is part of Dist-Zilla-Plugin-TemplateCJM 4.24 (October 3, 2015)
+our $VERSION = '5.000';
+# This file is part of Dist-Zilla-Plugin-TemplateCJM 5.000 (December 5, 2015)
 
 
 use Moose;
-use Moose::Autobox;
 use Moose::Util::TypeConstraints;
 use List::Util ();
 
@@ -97,7 +96,7 @@ sub setup_installer {
 
   # Get release date & changes from Changes file:
   my $changelog = $self->changelog;
-  my $changesFile = $files->grep(sub{ $_->name eq $changelog })->head
+  my $changesFile = List::Util::first { $_->name eq $changelog } @$files
       or die "No $changelog file\n";
 
   my ($release_date, $changes, $release_datetime) = $self->check_Changes($changesFile);
@@ -125,9 +124,10 @@ sub setup_installer {
     BROKEN => sub { $self->template_error(@_) },
   );
 
-  my $any = $self->template_files->any;
+  my %template_file = map {; $_ => 1 } @{ $self->template_files };
 
-  foreach my $file ($files->grep(sub { $_->name eq $any })->flatten) {
+  foreach my $file (@$files) {
+    next unless $template_file{ $file->name };
     $self->log('Processing ' . $file->name);
     $self->_cur_filename($file->name);
     $self->_cur_offset(0);
@@ -138,7 +138,7 @@ sub setup_installer {
   # Munge POD sections in modules:
   $files = $self->found_files;
 
-  foreach my $file ($files->flatten) {
+  foreach my $file (@$files) {
     $self->munge_file($file, \%data, \%parms);
   } # end foreach $file
 } # end setup_installer
@@ -339,10 +339,11 @@ sub build_instructions
   $indent = "\t" unless defined $indent;
 
   # Compute build instructions:
-  my $builder = $self->zilla->files
-                     ->map(sub{ $_->name })
-                     ->grep(sub{ /^(?:Build|Makefile)\.PL$/ })
-                     ->sort->head;
+  my ($builder) =
+      sort
+      grep { /^(?:Build|Makefile)\.PL$/ }
+      map { $_->name }
+      @{ $self->zilla->files };
 
   $self->log_fatal("Unable to locate Build.PL or Makefile.PL in distribution\n".
                    "TemplateCJM must come after ModuleBuild or MakeMaker")
@@ -468,8 +469,8 @@ Dist::Zilla::Plugin::TemplateCJM - Process templates, including version numbers
 
 =head1 VERSION
 
-This document describes version 4.24 of
-Dist::Zilla::Plugin::TemplateCJM, released October 3, 2015.
+This document describes version 5.000 of
+Dist::Zilla::Plugin::TemplateCJM, released December 5, 2015.
 
 =head1 SYNOPSIS
 
@@ -732,7 +733,7 @@ If there are no dependencies, the string C<None.> will be returned.
 
 =head1 DEPENDENCIES
 
-TemplateCJM requires L<Dist::Zilla> (4.300009 or later) and
+TemplateCJM requires L<Dist::Zilla> (5 or later) and
 L<Text::Template>.  I also recommend applying F<Template_strict.patch>
 to Text::Template.  This will add support for the STRICT option, which
 will help catch errors in your templates.
